@@ -35,8 +35,6 @@ namespace
     QString const MILE_SPEEDUNIT = "mph";
     QString const METER_UNIT = "m";
     QString const FEET_UNIT = "feet";
-    double const FEET_MULTIPLIER = 3.2808399;
-    double const METER_MULTIPLIER = 1.0;
     static const int FIX_TIMEOUT = 4000;
     double const DEFAULT_SPEED_TRESHOLD = 8.0;
     double const MIN_SPEED_TRESHOLD = 0.8;
@@ -295,14 +293,7 @@ double Odometer::getUnitMultiplier()
 
 double Odometer::getMeterMultiplier()
 {
-    if(Location::getUnit() == Location::KM)
-    {
-        return METER_MULTIPLIER;
-    }
-    else
-    {
-        return FEET_MULTIPLIER;
-    }
+    return Location::getMeterMultiplier();
 }
 
 QString Odometer::getMeterUnit()
